Complete columns in a dataframe
complete_columns.RdIf any column in cols is missing from data, this function adds it
and populates it with NA values.

complete_columns.RdIf any column in cols is missing from data, this function adds it
and populates it with NA values.