Skip to contents

Plot movement cost

Usage

plot_movement_cost(data, group_cols)

Arguments

data

A data frame containing the movement cost data with columns movement_cost and optionally a grouping column.

group_cols

A character vector of columns to group by, or "ref_date" for no grouping.

Value

A ggplot2 object representing the movement cost.