Function to compute the distribution function of a variable
compute_density.RdFunction to compute the distribution function of a variable
Arguments
- data
A data frame.
- group_col
A string naming a single column to group by, or
NULLfor no grouping.- measure_col
The name of the column for which the percentile values will be computed.
- binwidth
The width of the bins for grouping the measure values (default is 1).
- latest_measure
A logical value indicating whether to return only the measures for the latest reference date.