Skip to contents

a function to compute the proportion of missing values in a data frame

Usage

compute_global_coverage(data, digits = 2)

Arguments

data

A data frame.

digits

An integer specifying the number of decimal places to round the result to. Default is 2.

Value

A numeric value representing the proportion of missing values in the data frame.