compute_global_coverage.Rd
a function to compute the proportion of missing values in a data frame
compute_global_coverage(data, digits = 2)
A data frame.
An integer specifying the number of decimal places to round the result to. Default is 2.
A numeric value representing the proportion of missing values in the data frame.