Compute Growth Rate Summary Table
compute_growth.RdFilters to the first and last reference date within each group and computes the percentage change from first `ref_date` to last `ref_date`.

compute_growth.RdFilters to the first and last reference date within each group and computes the percentage change from first `ref_date` to last `ref_date`.