Compute group-wise proportions from counts
fastprop.Rdfastprop() computes the proportion of counts within groups.
It expects the input to already contain a count column named n
(for example the output of dplyr::count() or fastcount()).

fastprop.Rdfastprop() computes the proportion of counts within groups.
It expects the input to already contain a count column named n
(for example the output of dplyr::count() or fastcount()).