Find Duplicate Identifiers in a Data Frame
find_duplicate_ids.RdIdentifies duplicated values of a specified identifier column in a data frame or tibble. Returns a tibble with the identifier values that appear more than once and their counts.

find_duplicate_ids.RdIdentifies duplicated values of a specified identifier column in a data frame or tibble. Returns a tibble with the identifier values that appear more than once and their counts.