Fit a wage model with fixed effects
model_wage.RdFits a linear wage model based on a set of predictors and fixed effects.
Arguments
- data
A data frame containing the outcome, predictor, and fixed effects columns.
- outcome_var
Character. Name of the outcome column. Default
"gross_salary_lcu".- predictor_vars
A character vector. Names of predictor columns. Default
c("contract_type", "occupation_native", "educat7", "whours", "paygrade").- fixed_effects_vars
Character vector, or
NULLto fit without fixed effects. Names of fixed effects columns. Defaultc("personnel_id", "est_id", "ref_date").
Value
A fixest model object, as returned by fixest::feols().