Worldwide Bureaucracy Indicators
wwbi.RdThe Worldwide Bureaucracy Indicators (WWBI) database is a unique cross-national dataset on public sector employment and wages that aims to fill an information gap, thereby helping researchers, development practitioners, and policymakers gain a better understanding of the personnel dimensions of state capability, the footprint of the public sector within the overall labor market, and the fiscal implications of the public sector wage bill. The dataset is derived from administrative data and household surveys, thereby complementing existing, expert perception-based approaches.
Format
A data frame with 993 rows and 11 variables:
country_codecharacter World Bank country code.
yeardouble Year.
share_no_edudouble Share of public sector personnel with no education.
share_primary_edudouble Share of public sector personnel with primary education completed.
share_secondary_edudouble Share of public sector personnel with secondary education completed.
share_tertiary_edudouble Share of public sector personnel with tertiary education completed.
ps_wage_premium_edu_sectordouble Public sector wage premium in the education sector, compared to formal wage employees in the private sector.
ps_wage_premium_hea_sectordouble Public sector wage premium in the health sector, compared to formal wage employees in the private sector.
ps_wage_premium_femaledouble Public sector wage premium for female personnel, compared to formal wage employees in the private sector.
ps_wage_premium_maledouble Public sector wage premium for male personnel, compared to formal wage employees in the private sector.
ps_wage_premium_pooleddouble Public sector wage premium for all public sector personnel, compared to formal wage employees in the private sector.
ps_share_total_empdouble Public sector employment, as a share of total employment
ps_share_paid_empdouble Public sector employment, as a share of paid employment
ps_share_formal_empdouble Public sector employment, as a share of formal employment
ps_wage_premium_isced_ndouble Public sector wage premium for personnel with no education, compared to formal wage employees in the private sector.
ps_wage_premium_isced_1double Public sector wage premium for personnel with primary education completed, compared to formal wage employees in the private sector.
ps_wage_premium_isced_2_3double Public sector wage premium for personnel with secondary education completed, compared to formal wage employees in the private sector.
ps_wage_premium_isced_5t8double Public sector wage premium for personnel with tertiary education completed, compared to formal wage employees in the private sector.
ps_wage_premium_clerkdouble Public sector wage premium for personnel in clerical support occupations, compared to formal wage employees in the private sector.
ps_wage_premium_elementarydouble Public sector wage premium for personnel in elementary occupations, compared to formal wage employees in the private sector.
ps_wage_premium_professionaldouble Public sector wage premium for personnel in professional occupations, compared to formal wage employees in the private sector.
ps_wage_premium_managerdouble Public sector wage premium for personnel in managerial occupations, compared to formal wage employees in the private sector.
ps_wage_premium_technicaldouble Public sector wage premium for personnel in technical and associate professional occupations, compared to formal wage employees in the private sector.
World Bank https://data360.worldbank.org/en/int/dataset/WB_WWBI